about summary refs log tree commit diff stats
path: root/src/command/cmd_funcs.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/command/cmd_funcs.c')
-rw-r--r--src/command/cmd_funcs.c80
1 files changed, 40 insertions, 40 deletions
diff --git a/src/command/cmd_funcs.c b/src/command/cmd_funcs.c
index e800cc0a..ffa8a3d2 100644
--- a/src/command/cmd_funcs.c
+++ b/src/command/cmd_funcs.c
@@ -6,20 +6,20 @@
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -58,7 +58,7 @@
 #include <sys/wait.h>
 #include <readline/readline.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "log.h"
 #include "common.h"
 #include "command/cmd_funcs.h"
@@ -189,7 +189,7 @@ _string_matches_one_of(const char* what, const char* is, bool is_can_be_null, co
 }
 
 /*
  * Take a line of input and process it, return TRUE if profanity is to
  * continue, FALSE otherwise
  */
 gboolean
@@ -1344,7 +1344,7 @@ cmd_disconnect(ProfWin* window, const char* const command, gchar** args)
 gboolean
 cmd_quit(ProfWin* window, const char* const command, gchar** args)
 {
-    log_info("Profanity is shutting down...");
+    log_info("Profani-tty is shutting down…");
     exit(0);
     return FALSE;
 }
@@ -4951,7 +4951,7 @@ _add_omemo_stream(int* fd, FILE** fh, char** err)
     // Create temporary file for writing ciphertext.
     int tmpfd;
     char* tmpname = NULL;
-    if ((tmpfd = g_file_open_tmp("profanity.XXXXXX", &tmpname, NULL)) == -1) {
+    if ((tmpfd = g_file_open_tmp("profani-tty.XXXXXX", &tmpname, NULL)) == -1) {
         *err = "Unable to create temporary file for encrypted transfer.";
         return NULL;
     }
@@ -6550,7 +6550,7 @@ cmd_log(ProfWin* window, const char* const command, gchar** args)
 
     if (strcmp(subcmd, "shared") == 0) {
         _cmd_set_boolean_preference(value, command, "Shared log", PREF_LOG_SHARED);
-        cons_show("Setting only takes effect after saving and restarting Profanity.");
+        cons_show("Setting only takes effect after saving and restarting Profani-tty.");
         return TRUE;
     }
 
@@ -6900,7 +6900,7 @@ cmd_tray(ProfWin* window, const char* const command, gchar** args)
         return TRUE;
     }
 #else
-    cons_show("This version of Profanity has not been built with GTK Tray Icon support enabled");
+    cons_show("This version of Profani-tty has not been built with GTK Tray Icon support enabled");
     return TRUE;
 #endif
 }
@@ -7620,7 +7620,7 @@ cmd_pgp(ProfWin* window, const char* const command, gchar** args)
     cons_bad_cmd_usage(command);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with PGP support enabled");
+    cons_show("This version of Profani-tty has not been built with PGP support enabled");
     return TRUE;
 #endif
 }
@@ -7885,7 +7885,7 @@ cmd_otr_char(ProfWin* window, const char* const command, gchar** args)
     }
     cons_bad_cmd_usage(command);
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
 #endif
     return TRUE;
 }
@@ -7915,7 +7915,7 @@ cmd_otr_log(ProfWin* window, const char* const command, gchar** args)
     }
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -7928,7 +7928,7 @@ cmd_otr_libver(ProfWin* window, const char* const command, gchar** args)
     cons_show("Using libotr version %s", version);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -7969,7 +7969,7 @@ cmd_otr_policy(ProfWin* window, const char* const command, gchar** args)
     cons_show("OTR policy for %s set to: %s", contact_jid, choice);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -7988,7 +7988,7 @@ cmd_otr_gen(ProfWin* window, const char* const command, gchar** args)
     account_free(account);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8012,7 +8012,7 @@ cmd_otr_myfp(ProfWin* window, const char* const command, gchar** args)
     free(fingerprint);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8043,7 +8043,7 @@ cmd_otr_theirfp(ProfWin* window, const char* const command, gchar** args)
     free(fingerprint);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8132,7 +8132,7 @@ cmd_otr_start(ProfWin* window, const char* const command, gchar** args)
         return TRUE;
     }
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8162,7 +8162,7 @@ cmd_otr_end(ProfWin* window, const char* const command, gchar** args)
     otr_end_session(chatwin->barejid);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8192,7 +8192,7 @@ cmd_otr_trust(ProfWin* window, const char* const command, gchar** args)
     otr_trust(chatwin->barejid);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8222,7 +8222,7 @@ cmd_otr_untrust(ProfWin* window, const char* const command, gchar** args)
     otr_untrust(chatwin->barejid);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8257,7 +8257,7 @@ cmd_otr_secret(ProfWin* window, const char* const command, gchar** args)
     otr_smp_secret(chatwin->barejid, secret);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8293,7 +8293,7 @@ cmd_otr_question(ProfWin* window, const char* const command, gchar** args)
     otr_smp_question(chatwin->barejid, question, answer);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8328,7 +8328,7 @@ cmd_otr_answer(ProfWin* window, const char* const command, gchar** args)
     otr_smp_answer(chatwin->barejid, answer);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8341,7 +8341,7 @@ cmd_otr_sendfile(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OTR support enabled");
+    cons_show("This version of Profani-tty has not been built with OTR support enabled");
     return TRUE;
 #endif
 }
@@ -8682,7 +8682,7 @@ cmd_omemo_gen(ProfWin* window, const char* const command, gchar** args)
     cons_show("OMEMO crytographic materials generated. Your Device ID is %d.", omemo_device_id());
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -8760,7 +8760,7 @@ cmd_omemo_start(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -8791,7 +8791,7 @@ cmd_omemo_trust_mode(ProfWin* window, const char* const command, gchar** args)
     prefs_set_string(PREF_OMEMO_TRUST_MODE, args[1]);
 
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
 #endif
     return TRUE;
 }
@@ -8813,7 +8813,7 @@ cmd_omemo_char(ProfWin* window, const char* const command, gchar** args)
     }
     cons_bad_cmd_usage(command);
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
 #endif
     return TRUE;
 }
@@ -8843,7 +8843,7 @@ cmd_omemo_log(ProfWin* window, const char* const command, gchar** args)
     }
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -8886,7 +8886,7 @@ cmd_omemo_end(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -8956,7 +8956,7 @@ cmd_omemo_fingerprint(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9025,7 +9025,7 @@ cmd_omemo_trust(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9093,7 +9093,7 @@ cmd_omemo_untrust(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9111,7 +9111,7 @@ cmd_omemo_clear_device_list(ProfWin* window, const char* const command, gchar**
     cons_show("Cleared OMEMO device list");
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9136,7 +9136,7 @@ cmd_omemo_policy(ProfWin* window, const char* const command, gchar** args)
     cons_show("OMEMO policy is now set to: %s", choice);
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9161,7 +9161,7 @@ cmd_omemo_qrcode(ProfWin* window, const char* const command, gchar** args)
 
     return TRUE;
 #else
-    cons_show("This version of Profanity has not been built with OMEMO support enabled");
+    cons_show("This version of Profani-tty has not been built with OMEMO support enabled");
     return TRUE;
 #endif
 }
@@ -9223,7 +9223,7 @@ cmd_paste(ProfWin* window, const char* const command, gchar** args)
         free(clipboard_buffer);
     }
 #else
-    cons_show("This version of Profanity has not been built with GTK support enabled. It is needed for the clipboard feature to work.");
+    cons_show("This version of Profani-tty has not been built with GTK support enabled. It is needed for the clipboard feature to work.");
 #endif
 
     return TRUE;
@@ -9338,7 +9338,7 @@ cmd_avatar(ProfWin* window, const char* const command, gchar** args)
                 cons_show("Avatar updated successfully");
             }
 #else
-            cons_show("Profanity has not been built with GDK Pixbuf support enabled which is needed to scale the avatar when uploading.");
+        cons_show("Profani-tty has not been built with GDK Pixbuf support enabled which is needed to scale the avatar when uploading.");
 #endif
         } else if (g_strcmp0(args[0], "get") == 0) {
             avatar_get_by_nick(args[1], false);
@@ -6,20 +6,20 @@
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -6,20 +6,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -6,20 +6,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -189,7 +189,7 @@ _string_matches_one_of(const char* what, const char* is, bool is_can_be_null, co
 
 /*
- * Take a line of input and process it, return TRUE if profanity is to
+ * Take a line of input and process it, return TRUE if profani-tty is to
  * continue, FALSE otherwise
  */